[![Templafirm](https://github.com/tawa-ai/templafirm/actions/workflows/templafirm.yaml/badge.svg)](https://github.com/tawa-ai/templafirm/actions/workflows/templafirm.yaml)
[![Upload Templafirm to PyPi](https://github.com/tawa-ai/templafirm/actions/workflows/release.yaml/badge.svg)](https://github.com/tawa-ai/templafirm/actions/workflows/release.yaml)

# Templafirm

Templating package for creating dynamic terraform resources programmatically.

